###############################################################################
###############################################################################
##
##  Copyright (C) 2004 Red Hat, Inc.  All rights reserved.
##
##  This copyrighted material is made available to anyone wishing to use,
##  modify, copy, or redistribute it subject to the terms and conditions
##  of the GNU General Public License v.2.
##
###############################################################################
###############################################################################
%define _unpackaged_files_terminate_build 1

%{!?kernel: %{expand: %%define kernel %(uname -r)}}
%define kversion %(echo %{kernel} | sed -e s/smp// -)

%define kernel_ver_str %(echo %{kversion} | tr -s '-' '_')

%define kmajor %(echo %{kversion} | cut -d'-' -f1)
%define kminor %(echo %{kversion} | cut -d'-' -f2)
%define arch i686
#define kconfig  /usr/src/linux-%(echo %{kernel})/configs/kernel-%{kmajor}-i686%{?ksmp}.config

%define KERNEL_VERSION 2
%define KERNEL_PATCHLEVEL 6
%define KERNEL_SUBLEVEL 9

%define buildup 1
%define buildsmp 1
%define buildhugemem 1
%define arch i686

%ifnarch i686
%define buildhugemem 0
%endif

%ifnarch i686 x86_64 athlon
%define buildsmp 0
%endif 

%define mrelease 2.PU_IAS.1

Name: ndiswrapper
Version: 1.0
Release: %{mrelease}
License: GPL
GROUP: System Environment/Base
Summary: ndiswrapper allows you to use windows XP drivers for that WLAN card without proper Linux drivers.
BuildRequires: rsync flex bison
BuildRequires: kernel-devel = %{kversion}
ExcludeArch: i386 ppc ppc64 s390 s390x
URL: http://ndiswrapper.sourceforge.net
Source0: %{name}-%{version}.tar.gz

# Patches are applied later - after the source is extracted
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
ome wireless LAN vendors refuse to release hardware specifications or
drivers for their products for operating systems other than Microsoft
Windows. The ndiswrapper project makes it possible to use such
hardware with Linux by means of a loadable kernel module that "wraps
around" NDIS (Windows network driver API) drivers.  This rpm contains
just the userspace tools. You will also need the kernel module rpm.

%if %{buildup}
%package -n kernel-%{name}
Release: %{mrelease}_%{kernel_ver_str}
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Requires: kernel = %{kversion}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description -n kernel-%{name}
Kernel module for ndiswrapper.
%endif

%if %{buildsmp}
%package -n kernel-smp-%{name}
Release: %{mrelease}_%{kernel_ver_str}
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Requires: kernel-smp = %{kversion}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description -n kernel-smp-%{name}
Kernel module for ndiswrapper.
%endif

%if %{buildhugemem}
%package -n kernel-hugemem-%{name}
Release: %{mrelease}_%{kernel_ver_str}
GROUP: System Environment/Base
Summary: Ndiswrapper kernel module
Requires: kernel-hugemem = %{kversion}
Requires: ndiswrapper
Provides: kernel-module kernel-modules

%description -n kernel-hugemem-%{name}
Kernel module for ndiswrapper.
%endif

####################################################################################
##  THE PREP SECTION
####################################################################################
%prep
echo ping
%setup -q
echo pong
####################################################################################
##  THE BUILD SECTION
####################################################################################
%build
BUILD_TOPDIR=`pwd`

BuildSistina(){
	cpu_type=$1
	flavor=$2
	kernel_src=/usr/src/kernels/%{kversion}-%{arch}
	# Kernel tree setup
	if [ -d $kernel_src/. ]; then
		echo "Kernel found."
	else
		echo "Kernel not found."
		exit 1
	fi

	rsync -aH $kernel_src/ linux$flavor
	#make -C linux$flavor oldconfig
	#make -C linux$flavor mrproper
	#[ -d linux$flavor/configs ] || exit 1
	#cat linux$flavor/configs/kernel*${cpu_type}${flavor:+-}$flavor.config >> linux$flavor/.config
	make -C linux$flavor oldconfig \
		VERSION=%{KERNEL_VERSION} \
		PATCHLEVEL=%{KERNEL_PATCHLEVEL} \
		SUBLEVEL=%{KERNEL_SUBLEVEL} \
		EXTRAVERSION=-%{kminor}$flavor
	cat > linux$flavor/.config <<EOF
CONFIG_IPW2100=m
EOF
case flavor in
	hugemem)
		sed -e 's/CONFIG_M686=.*/# CONFIG_M686 is not set/' -i linux$flavour/.config
		sed -e 's/# CONFIG_MPENTIUMIII is not set/CONFIG_MPENTIUMIII=y/' -i linux$flavour/.config
		sed -e 's/# CONFIG_X86_4G is not set/CONFIG_X86_4G=y/' -i linux$flavour/.config
	;;

	smp)
	#we get smp for free
	;;

	default)
		sed -e 's/CONFIG_SMP=.*/# CONFIG_SMP is not set/' -i linux$flavour/.config
		sed -e 's/CONFIG_X86_SMP=.*/# CONFIG_X86_SMP is not set/' -i linux$flavour/.config
		sed -e 's/CONFIG_HOTPLUG_PCI=.*/# CONFIG_HOTPLUG_PCI is not set/' -i linux$flavour/.config
		sed -e 's/CONFIG_PROFILING=.*/# CONFIG_PROFILING is not set/' -i linux$flavour/.config
		sed -e 's/CONFIG_OPROFILE=.*/# CONFIG_OPROFILE is not set/' -i linux$flavour/.config
		sed -e 's/CONFIG_HIGHMEM64G=.*/# CONFIG_HIGHMEM64G is not set/' -i linux$flavour/.config
	;;
esac
	make KSRC=`pwd`/linux$flavor KVERS=%{kversion}$flavor
	mkdir ../installed-$flavor
	#make install KSRC=`pwd`/linux$flavor KVERS=%{kversion}$flavor KMISC=installed-$flavor
	mv ndiswrapper.ko ../installed-$flavor
	make clean
	rm -rf linux$flavor
}

cd driver

%if %{buildhugemem}
BuildSistina %{_target_cpu} hugemem
%endif

%if %{buildsmp}
BuildSistina %{_target_cpu} smp
%endif

%if %{buildup}
BuildSistina %{_target_cpu}
%endif

cd ..

# finally, make the utilities
make -C utils

####################################################################################
##  THE INSTALL SECTION
####################################################################################
%install
rm -rf $RPM_BUILD_ROOT
doinstall() {
	flavor=$1
	mkdir -p $RPM_BUILD_ROOT/lib/modules/%{kversion}$flavor/kernel/drivers/misc/
	cp installed-$flavor/* $RPM_BUILD_ROOT/lib/modules/%{kversion}$flavor/kernel/drivers/misc
}

%if %{buildhugemem}
doinstall hugemem
%endif

%if %{buildsmp}
doinstall smp
%endif

%if %{buildup}
doinstall
%endif

cd utils
mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT/usr/sbin
install -m 755 loadndisdriver $RPM_BUILD_ROOT/sbin
install -m 755 ndiswrapper ndiswrapper-buginfo $RPM_BUILD_ROOT/usr/sbin

####################################################################################
##  THE CLEAN SECTION
####################################################################################
%clean
rm -rf $RPM_BUILD_ROOT


####################################################################################
##  THE POST/POSTUN SECTION
####################################################################################
%if %{buildup}
%post -n kernel-%{name}
depmod -a

%postun -n kernel-%{name}
depmod -a
%endif

%if %{buildsmp}
%post -n kernel-smp-%{name}
depmod -a

%postun -n kernel-smp-%{name}
depmod -a
%endif

%if %{buildhugemem}
%post -n kernel-hugemem-%{name}
depmod -a

%postun -n kernel-hugemem-%{name}
depmod -a
%endif

%files
%defattr(0755,root,root)
%doc README AUTHORS ChangeLog INSTALL
/sbin/*
/usr/sbin/*

%if %{buildup}
%files -n kernel-%{name}
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kversion}/kernel/drivers/misc/*
%endif

%if %{buildsmp}
%files -n kernel-smp-%{name}
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kversion}smp/kernel/drivers/misc/*
%endif

%if %{buildhugemem}
%files -n kernel-hugemem-%{name}
%defattr(-,root,root,-)
# Modules
/lib/modules/%{kversion}hugemem/kernel/drivers/misc/*
%endif

%changelog
* Fri Feb 25 2005 Thomas Uphill <uphill@math.ias.edu>
- update for 2.6

* Mon Aug 2 2004 Josko Plazonic <plazonic@math.princeton.edu>
- first build
